# Example (V.3) 

# Get on the right directory
################################################################################
wd <- "C:/CIT/projets HS3/3-RELB Longy/article G2I/G2I tool final"      
# !!!! change wd : set the correct folder !!!!!!!
setwd(wd)

# 1. Loading R functions
################################################################################
source("miscellaneous functions.R")
source("genomic score functions.R")


# 2. Load the CIT dataset
################################################################################
citannot <- get(load("CIT cghbac series - all needed data.RData"))[[1]]


# 3. Learn the decision rule (training set = CIT dataset)
################################################################################
citres <- g2i.learn(  sampleannot = citannot)
 
################
# IMPORTANT NB : each run (with default options) may yield different thresholds
# and thus results(because it uses random initialization steps) 
################



# 4. Predict G2I scores according to the decision rule 
######################################################

# Use thresholds obtained in the run underlying Figure 2A+B
citres$nb1 <- 42.1
citres$nb3 <- 64.7
citres$txp1 <- .484
citres$txp3 <- .352   

# Predict G2I groups according to these thresholds on CIT data
tmp <- g2i.predict(citres,citannot,FALSE)

# Plot the figure (= figure 2 A & B)
pdf("Figure 2AB.pdf",16.53/2,  11.69)
g2i.plot(tmp,FALSE,posTest="bottom")  # >> logrank p < 3e-10 ;  |G1|=19 ; |G2|=88 ;   |G3| = 28
graphics.off()

# Load the Gravier (pretreated) data    
# NB : to see how to pretreat the external data, go to point 5
gravierannot <- get(load("Gravier pretreated.RData"))

# Predict G2I groups on Gravier data
gravierres <- g2i.predict(citres, gravierannot,FALSE)

# Plot the results (= figure 3)
pdf("Figure 3.pdf",16.53/2,  11.69)
g2i.plot(gravierres,FALSE)  # >> logrank p = 1e-5  ; |G1|=30 ; |G2|=119 ;   |G3| = 19
graphics.off()
      

# 5. Pretreat the external dataset (here : Gravier et al- 2010)
################################################################################
gravier <- get(load("Gravier series - all needed data.RData"))
# NB : this dataset is made of 6 subsets with different CGH BAC chips

gravier.1 <- gravier[c(1,2,3)]
names(gravier.1)   <- c("sampleannot","cghannot","gnldata")

gravier.2 <- gravier[c(1,2,4)]
names(gravier.2)   <- c("sampleannot","cghannot","gnldata")

gravier.3 <- gravier[c(1,2,5)]
names(gravier.3)   <- c("sampleannot","cghannot","gnldata")

gravier.4 <- gravier[c(1,2,6)]
names(gravier.4)   <- c("sampleannot","cghannot","gnldata")

gravier.5 <- gravier[c(1,2,7)]
names(gravier.5)   <- c("sampleannot","cghannot","gnldata")

gravier.6 <- gravier[c(1,2,8)]
names(gravier.6)   <- c("sampleannot","cghannot","gnldata")

# 5. Predicting G2I groups on the external dataset
################################################################################

# (i) pretreating each subset
grav1 <- g2i.pretreat( gnldata     = gravier.1$gnldata,
                       cghannot    = gravier.1$cghannot,
                       sampleannot = gravier.1$sampleannot)
grav2 <- g2i.pretreat( gnldata     = gravier.2$gnldata,
                       cghannot    = gravier.2$cghannot,
                       sampleannot = gravier.2$sampleannot)
grav3 <- g2i.pretreat( gnldata     = gravier.3$gnldata,
                       cghannot    = gravier.3$cghannot,
                       sampleannot = gravier.3$sampleannot)
grav4 <- g2i.pretreat( gnldata     = gravier.4$gnldata,
                       cghannot    = gravier.4$cghannot,
                       sampleannot = gravier.4$sampleannot)
grav5 <- g2i.pretreat( gnldata     = gravier.5$gnldata,
                       cghannot    = gravier.5$cghannot,
                       sampleannot = gravier.5$sampleannot)
grav6 <- g2i.pretreat( gnldata     = gravier.6$gnldata,
                       cghannot    = gravier.6$cghannot,
                       sampleannot = gravier.6$sampleannot)

# (ii) getting pretreated data of the 6 subsets in one  table
gravierannot <- gravier[["samples.annotations"]]

gravierannot[rownames(grav1),"TXP"] <- grav1$TXP
gravierannot[rownames(grav1),"NB"]  <- grav1$NB

gravierannot[rownames(grav2),"TXP"] <- grav2$TXP
gravierannot[rownames(grav2),"NB"]  <- grav2$NB

gravierannot[rownames(grav3),"TXP"] <- grav3$TXP
gravierannot[rownames(grav3),"NB"]  <- grav3$NB

gravierannot[rownames(grav4),"TXP"] <- grav4$TXP
gravierannot[rownames(grav4),"NB"]  <- grav4$NB

gravierannot[rownames(grav5),"TXP"] <- grav5$TXP
gravierannot[rownames(grav5),"NB"]  <- grav5$NB

gravierannot[rownames(grav6),"TXP"] <- grav6$TXP
gravierannot[rownames(grav6),"NB"]  <- grav6$NB

save(gravierannot,file="Gravier pretreated.RData")






